#!/bin/bash

#
# guess the DNS domainname:
# if dnsdomainname gives something sensible, use it
#    exludes "localdomain" and similar, should have a "."
# otherwise try to guess based on the IP on the "default gateway" interface
# may fail completely e.g. for NATed machines on a private network
#   we could use "traceroute" to discover this, but why bother?

export LANG=C

guess_default_if_name() {
  local defdev_tmp=$(/sbin/busybox iproute list | /sbin/busybox grep default)
  local defdev=${defdev_tmp##default via*dev }

  if [ -z "$defdev" ]; then
    return 1
  fi


  local def_ip_tmp1=$(/sbin/busybox ipaddr show dev ${defdev} | /sbin/busybox grep "inet ")
  
  local def_ip_tmp2=${def_ip_tmp1%%/?? brd*}
  local def_ip=${def_ip_tmp2##*inet }

  if [ -z "$def_ip" -o -n "${def_ip//*.*.*.*}" ]; then
    return 1
  fi

#  local def_name_tmp1=$(/sbin/busybox nslookup ${def_ip} 137.138.16.5 | /sbin/busybox grep "Name:")
#  local def_name_tmp2=${def_name_tmp1##Name: }
#  on 5.3 above does not work: nslookup from busybox wants to go via libreslove no matter what
  local def_name_tmp1=$(/usr/bin/nslookup ${def_ip} 137.138.16.5 | /sbin/busybox grep "name =")
  local def_name_tmp2=${def_name_tmp1##*name = } 
  def_name=${def_name_tmp2%%.}
  if [ "$def_name" != "${def_name//*NXDOMAIN*}" ]; then
     def_name=''
     return 1
  fi
  if [ "$def_name" != "${def_name//*connection*timed*out*}" ]; then
     def_name=''
     return 1
  fi



  # special and unfortunate hack for the CERN Technical Network
  case "$def_ip" in
      172.18.*)
	 def_name=somewhere.tn.cern.ch
         ;;
  esac
  #$def_name
}


guess_default_if_name
if [ -n "$def_name" ]; then
  echo ${def_name#*.}
else
  echo ""
fi





